@@ -1,8 +1,12 @@
+import types
+
+from skfem.visuals.matplotlib import draw, show
+
 from .process import process
 
 
 def triangulate(
-    corner_points, max_refloops=10, theta=0.8, smooth_steps=50, quality=0.9
+    corner_points, max_refloops=20, theta=0.8, smooth_steps=50, quality=0.9
 ):
     from .criterion import avg_quality
     from .initial import cdt
@@ -11,7 +15,7 @@ def triangulate(
     from .smooth import cpt
     from .solve import laplace
 
-    return process(
+    m = process(
         initial=cdt,
         solve=laplace,
         mark=adaptive_theta,
@@ -24,3 +28,7 @@ def triangulate(
         smooth_steps=smooth_steps,
         quality=quality,
     )
+    m.draw = types.MethodType(lambda self, **kwargs: draw(self, **kwargs), m)
+    m.show = types.MethodType(lambda self, **kwargs: show(self, **kwargs), m)
+
+    return m
